@@ -107,3 +107,37 @@ if ($file_average > $string_average) {
 } else {
     print STDERR "It is recommend you use the File Handle mode for your framebuffer device, UNLESS you will be using the 'replace_color' method a lot\n";
 }
+
+=head1 NAME
+
+Memory Mapped versus File Handle test
+
+=head1 DESCRIPTION
+
+Tests the framebuffer device to see whether memory mapped string mode or direct file handle mode is faster for the specific device.
+
+Usually memory mapped mode is faster, but SOME TFT modules with SPI interfaces are considersably faster in file handle mode.
+
+=head1 SYNOPSIS
+
+ perl mmapvsfile.pl [device number]
+
+=head1 OPTION
+
+=over 2
+
+=item C<device number>
+
+The framebuffer device number to use (default 0)
+
+=back
+
+=head2 Example
+
+=over 4
+
+ perl mmapvsfile.pl 1
+
+=back
+
+=cut
