@@ -65,8 +65,8 @@ vertical_gradient_boxes();
 horizontal_gradient_boxes();
 rounded_boxes();
 filled_rounded_boxes();
-vertical_gradient_boxes();
-horizontal_gradient_boxes();
+vertical_gradient_rounded_boxes();
+horizontal_gradient_rounded_boxes();
 circles();
 filled_circles();
 vertical_gradient_circles();
@@ -617,13 +617,14 @@ sub beziers {
 sub truetype_fonts {
     print_it($F, 'Testing TrueType Font Rendering (random height/width)');
 
-    my $g = time + $factor;
+    my @fonts = (keys %{$F->{'FONTS'}});
+    my $g = time + $factor * 2;
     while (time < $g) {
         my $x  = int(rand(600 * $xm));
         my $y  = int(rand(900 * $ym));
-        my $h  = ($YY < 128) ? (6 + rand(60)) : (8 + int(rand(300 * $ym)));
-        my $ws = ($XX < 256) ? rand(2) : rand(4);
-
+        my $h  = ($YY <= 240 || $F->{'BITS'} == 16) ? (6 + rand(60)) : (8 + int(rand(300 * $ym)));
+        my $ws = ($XX <= 320 || $F->{'BITS'} == 16) ? rand(2) : rand(4);
+        my $font = $fonts[int(rand(scalar(@fonts)))];
         my $b = $F->ttf_print(
             {
                 'x'            => $x,
@@ -632,8 +633,10 @@ sub truetype_fonts {
                 'wscale'       => $ws,
                 'color'        => sprintf('%02x%02x%02x%02x', int(rand(256)), int(rand(256)), int(rand(256)),255),
                 'text'         => 'GFB',
+                'font_path'    => $F->{'FONTS'}->{$font}->{'path'},
+                'face'         => $F->{'FONTS'}->{$font}->{'font'},
                 'bounding_box' => 1,
-                'center'       => 3
+#                'center'       => 3
             }
         );
         if (defined($b)) {
